@@ -1,14 +1,13 @@
 /* ISC license. */
 
 #include <skalibs/nonposix.h>
-
 #include <errno.h>
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <string.h>
 
+#include <skalibs/socket.h>
 #include <skalibs/posixishard.h>
-#include <skalibs/webipc.h>
 
 ssize_t ipc_send (int fd, char const *s, size_t len, char const *path)
 {
