@@ -6,7 +6,7 @@
 
 #ifdef SKALIBS_FLAG_CLOCKISTAI
 
-int tai_from_sysclock (tai_t *t, uint64_t u)
+int tai_from_sysclock (tai *t, uint64_t u)
 {
   return tai_u64(t, u + 10U) ;
 }
@@ -15,7 +15,7 @@ int tai_from_sysclock (tai_t *t, uint64_t u)
 
 #include <skalibs/djbtime.h>
 
-int tai_from_sysclock (tai_t *t, uint64_t u)
+int tai_from_sysclock (tai *t, uint64_t u)
 {
   return tai_from_utc(t, u) ;
 }
